emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[nongnu] elpa/gruvbox-theme 557d4b6ba0 134/258: Split up theme variant i


From: ELPA Syncer
Subject: [nongnu] elpa/gruvbox-theme 557d4b6ba0 134/258: Split up theme variant into files instead of using variables
Date: Sat, 1 Jan 2022 01:59:37 -0500 (EST)

branch: elpa/gruvbox-theme
commit 557d4b6ba04a37137ecb12c00c387e4ebccd3676
Author: Martijn Terpstra <bigmartijn@gmail.com>
Commit: Jason Milkins <jasonm23@users.noreply.github.com>

    Split up theme variant into files instead of using variables
---
 gruvbox-dark-theme.el => gruvbox-dark-hard-theme.el    | 18 +++++++-----------
 gruvbox-dark-theme.el => gruvbox-dark-medium-theme.el  | 18 +++++++-----------
 gruvbox-dark-theme.el => gruvbox-dark-soft-theme.el    | 18 +++++++-----------
 gruvbox-light-theme.el => gruvbox-light-hard-theme.el  | 18 +++++++-----------
 ...box-light-theme.el => gruvbox-light-medium-theme.el | 18 +++++++-----------
 gruvbox-light-theme.el => gruvbox-light-soft-theme.el  | 14 +++++---------
 gruvbox-theme.el                                       |  8 ++------
 gruvbox.el                                             | 10 ----------
 8 files changed, 42 insertions(+), 80 deletions(-)

diff --git a/gruvbox-dark-theme.el b/gruvbox-dark-hard-theme.el
similarity index 91%
copy from gruvbox-dark-theme.el
copy to gruvbox-dark-hard-theme.el
index e9e77826ea..0833de4c23 100644
--- a/gruvbox-dark-theme.el
+++ b/gruvbox-dark-hard-theme.el
@@ -1,4 +1,4 @@
-;;; gruvbox-dark-theme.el --- A retro-groove colour theme for Emacs
+;;; gruvbox-dark-hard-theme.el --- A retro-groove colour theme for Emacs
 
 ;; Copyright (c) 2013 Lee Machin
 ;; Copyright (c) 2013-2016 Greduan
@@ -51,8 +51,8 @@
 (require 'gruvbox)
 
 (gruvbox-deftheme
- gruvbox-dark
- "A retro-groove colour theme (dark version)"
+ gruvbox-dark-hard
+ "A retro-groove colour theme (dark version, hard contrast)"
 
  ((((class color) (min-colors #xFFFFFF))        ; col 1 GUI/24bit
    ((class color) (min-colors #xFF)))           ; col 2 Xterm/256
@@ -116,13 +116,9 @@
   (gruvbox-aquamarine4     "#83A598" "#87af87")
   (gruvbox-turquoise4      "#61ACBB" "#5fafaf")
 
-  (gruvbox-bg (cl-case gruvbox-contrast
-                (hard gruvbox-dark0_hard)
-                (soft gruvbox-dark0_soft)
-                ;; Medium by default.
-                (t    gruvbox-dark0))))
+  (gruvbox-bg gruvbox-dark0_hard))
 
- (custom-theme-set-variables 'gruvbox-dark
+ (custom-theme-set-variables 'gruvbox-dark-hard
                              `(ansi-color-names-vector
                                [,gruvbox-dark1
                                 ,gruvbox-neutral_red
@@ -140,10 +136,10 @@
                   (file-name-as-directory
                    (file-name-directory load-file-name))))
 
-(provide-theme 'gruvbox-dark)
+(provide-theme 'gruvbox-dark-hard)
 
 ;; Local Variables:
 ;; eval: (when (fboundp 'rainbow-mode) (rainbow-mode +1))
 ;; End:
 
-;;; gruvbox-dark-theme.el ends here
+;;; gruvbox-dark-hard-theme.el ends here
diff --git a/gruvbox-dark-theme.el b/gruvbox-dark-soft-theme.el
similarity index 91%
rename from gruvbox-dark-theme.el
rename to gruvbox-dark-soft-theme.el
index e9e77826ea..e861ad202a 100644
--- a/gruvbox-dark-theme.el
+++ b/gruvbox-dark-soft-theme.el
@@ -1,4 +1,4 @@
-;;; gruvbox-dark-theme.el --- A retro-groove colour theme for Emacs
+;;; gruvbox-dark-soft-theme.el --- A retro-groove colour theme for Emacs
 
 ;; Copyright (c) 2013 Lee Machin
 ;; Copyright (c) 2013-2016 Greduan
@@ -51,8 +51,8 @@
 (require 'gruvbox)
 
 (gruvbox-deftheme
- gruvbox-dark
- "A retro-groove colour theme (dark version)"
+ gruvbox-dark-soft
+ "A retro-groove colour theme (dark version, soft contrast)"
 
  ((((class color) (min-colors #xFFFFFF))        ; col 1 GUI/24bit
    ((class color) (min-colors #xFF)))           ; col 2 Xterm/256
@@ -116,13 +116,9 @@
   (gruvbox-aquamarine4     "#83A598" "#87af87")
   (gruvbox-turquoise4      "#61ACBB" "#5fafaf")
 
-  (gruvbox-bg (cl-case gruvbox-contrast
-                (hard gruvbox-dark0_hard)
-                (soft gruvbox-dark0_soft)
-                ;; Medium by default.
-                (t    gruvbox-dark0))))
+  (gruvbox-bg gruvbox-dark0_soft))
 
- (custom-theme-set-variables 'gruvbox-dark
+ (custom-theme-set-variables 'gruvbox-dark-soft
                              `(ansi-color-names-vector
                                [,gruvbox-dark1
                                 ,gruvbox-neutral_red
@@ -140,10 +136,10 @@
                   (file-name-as-directory
                    (file-name-directory load-file-name))))
 
-(provide-theme 'gruvbox-dark)
+(provide-theme 'gruvbox-dark-soft)
 
 ;; Local Variables:
 ;; eval: (when (fboundp 'rainbow-mode) (rainbow-mode +1))
 ;; End:
 
-;;; gruvbox-dark-theme.el ends here
+;;; gruvbox-dark-soft-theme.el ends here
diff --git a/gruvbox-light-theme.el b/gruvbox-light-hard-theme.el
similarity index 91%
copy from gruvbox-light-theme.el
copy to gruvbox-light-hard-theme.el
index b3fb18e6cc..0355024dfa 100644
--- a/gruvbox-light-theme.el
+++ b/gruvbox-light-hard-theme.el
@@ -1,4 +1,4 @@
-;;; gruvbox-light-theme.el --- A retro-groove colour theme for Emacs
+;;; gruvbox-light-hard-theme.el --- A retro-groove colour theme for Emacs
 
 ;; Copyright (c) 2013 Lee Machin
 ;; Copyright (c) 2013-2016 Greduan
@@ -51,8 +51,8 @@
 (require 'gruvbox)
 
 (gruvbox-deftheme
- gruvbox-light
- "A retro-groove colour theme (light version)"
+ gruvbox-light-hard
+ "A retro-groove colour theme (light version, hard contrast)"
 
  ((((class color) (min-colors #xFFFFFF))        ; col 1 GUI/24bit
    ((class color) (min-colors #xFF)))           ; col 2 Xterm/256
@@ -116,13 +116,9 @@
   (gruvbox-aquamarine4     "#83A598" "#87af87")
   (gruvbox-turquoise4      "#61ACBB" "#5fafaf")
 
-  (gruvbox-bg (cl-case gruvbox-contrast
-                (hard gruvbox-dark0_hard)
-                (soft gruvbox-dark0_soft)
-                ;; Medium by default.
-                (t    gruvbox-dark0))))
+  (gruvbox-bg gruvbox-dark0_hard))
 
- (custom-theme-set-variables 'gruvbox-light
+ (custom-theme-set-variables 'gruvbox-light-hard
                              `(ansi-color-names-vector
                                [,gruvbox-dark1
                                 ,gruvbox-neutral_red
@@ -140,10 +136,10 @@
                   (file-name-as-directory
                    (file-name-directory load-file-name))))
 
-(provide-theme 'gruvbox-light)
+(provide-theme 'gruvbox-light-hard)
 
 ;; Local Variables:
 ;; eval: (when (fboundp 'rainbow-mode) (rainbow-mode +1))
 ;; End:
 
-;;; gruvbox-light-theme.el ends here
+;;; gruvbox-light-hard-theme.el ends here
diff --git a/gruvbox-light-theme.el b/gruvbox-light-soft-theme.el
similarity index 93%
rename from gruvbox-light-theme.el
rename to gruvbox-light-soft-theme.el
index b3fb18e6cc..adf68ee0b6 100644
--- a/gruvbox-light-theme.el
+++ b/gruvbox-light-soft-theme.el
@@ -1,4 +1,4 @@
-;;; gruvbox-light-theme.el --- A retro-groove colour theme for Emacs
+;;; gruvbox-light-soft-theme.el --- A retro-groove colour theme for Emacs
 
 ;; Copyright (c) 2013 Lee Machin
 ;; Copyright (c) 2013-2016 Greduan
@@ -51,7 +51,7 @@
 (require 'gruvbox)
 
 (gruvbox-deftheme
- gruvbox-light
+ gruvbox-light-soft
  "A retro-groove colour theme (light version)"
 
  ((((class color) (min-colors #xFFFFFF))        ; col 1 GUI/24bit
@@ -116,13 +116,9 @@
   (gruvbox-aquamarine4     "#83A598" "#87af87")
   (gruvbox-turquoise4      "#61ACBB" "#5fafaf")
 
-  (gruvbox-bg (cl-case gruvbox-contrast
-                (hard gruvbox-dark0_hard)
-                (soft gruvbox-dark0_soft)
-                ;; Medium by default.
-                (t    gruvbox-dark0))))
+  (gruvbox-bg gruvbox-dark0_soft))
 
- (custom-theme-set-variables 'gruvbox-light
+ (custom-theme-set-variables 'gruvbox-light-soft
                              `(ansi-color-names-vector
                                [,gruvbox-dark1
                                 ,gruvbox-neutral_red
@@ -140,7 +136,7 @@
                   (file-name-as-directory
                    (file-name-directory load-file-name))))
 
-(provide-theme 'gruvbox-light)
+(provide-theme 'gruvbox-light-soft)
 
 ;; Local Variables:
 ;; eval: (when (fboundp 'rainbow-mode) (rainbow-mode +1))
diff --git a/gruvbox-theme.el b/gruvbox-theme.el
index e440d4c303..2bc8f85def 100644
--- a/gruvbox-theme.el
+++ b/gruvbox-theme.el
@@ -52,7 +52,7 @@
 
 (gruvbox-deftheme
  gruvbox
- "A retro-groove colour theme (dark version)"
+ "A retro-groove colour theme"
 
  ((((class color) (min-colors #xFFFFFF))        ; col 1 GUI/24bit
    ((class color) (min-colors #xFF)))           ; col 2 Xterm/256
@@ -116,11 +116,7 @@
   (gruvbox-aquamarine4     "#83A598" "#87af87")
   (gruvbox-turquoise4      "#61ACBB" "#5fafaf")
 
-  (gruvbox-bg (cl-case gruvbox-contrast
-                (hard gruvbox0_hard)
-                (soft gruvbox0_soft)
-                ;; Medium by default.
-                (t    gruvbox0))))
+  (gruvbox-bg gruvbox0))
 
  (custom-theme-set-variables 'gruvbox
                              `(ansi-color-names-vector
diff --git a/gruvbox.el b/gruvbox.el
index 6fc8f72af6..b22d48893b 100644
--- a/gruvbox.el
+++ b/gruvbox.el
@@ -53,16 +53,6 @@
 (unless (>= emacs-major-version 24)
   (error "Requires Emacs 24 or later"))
 
-(defgroup gruvbox nil
-  "Customizations for gruvbox color theme"
-  :group 'faces)
-
-(defcustom gruvbox-contrast 'medium
-  "Contrast level for the theme background.
-Valid options are \"soft\", \"medium\" and \"hard\""
-  :options '(soft medium hard)
-  :group   'gruvbox)
-
 ;;;###autoload
 (and load-file-name
      (boundp 'custom-theme-load-path)



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/gruvbox-dark-theme.el b/gruvbox-dark-medium-theme.el
similarity index 91%
copy from gruvbox-dark-theme.el
copy to gruvbox-dark-medium-theme.el
index e9e77826ea..eff2651641 100644
--- a/gruvbox-dark-theme.el
+++ b/gruvbox-dark-medium-theme.el
@@ -1,4 +1,4 @@
 ;;; gruvbox-dark-theme.el --- A retro-groove colour theme for Emacs
 
 ;; Copyright (c) 2013 Lee Machin
 ;; Copyright (c) 2013-2016 Greduan
@@ -51,8 +51,8 @@
 (require 'gruvbox)
 
 (gruvbox-deftheme
- gruvbox-dark
- "A retro-groove colour theme (dark version)"
+ gruvbox-dark-medium
+ "A retro-groove colour theme (dark version, medium contrast)"
 
  ((((class color) (min-colors #xFFFFFF))        ; col 1 GUI/24bit
    ((class color) (min-colors #xFF)))           ; col 2 Xterm/256
@@ -116,13 +116,9 @@
   (gruvbox-aquamarine4     "#83A598" "#87af87")
   (gruvbox-turquoise4      "#61ACBB" "#5fafaf")
 
-  (gruvbox-bg (cl-case gruvbox-contrast
-                (hard gruvbox-dark0_hard)
-                (soft gruvbox-dark0_soft)
-                ;; Medium by default.
-                (t    gruvbox-dark0))))
+  (gruvbox-bg gruvbox-dark0))
 
- (custom-theme-set-variables 'gruvbox-dark
+ (custom-theme-set-variables 'gruvbox-dark-medium
                              `(ansi-color-names-vector
                                [,gruvbox-dark1
                                 ,gruvbox-neutral_red
@@ -140,10 +136,10 @@
                   (file-name-as-directory
                    (file-name-directory load-file-name))))
 
-(provide-theme 'gruvbox-dark)
+(provide-theme 'gruvbox-dark-medium)
 
 ;; Local Variables:
 ;; eval: (when (fboundp 'rainbow-mode) (rainbow-mode +1))
 ;; End:
 
-;;; gruvbox-dark-theme.el ends here
+;;; gruvbox-dark-medium-theme.el ends here
@@ -1,4 +1,4 @@
-;;; gruvbox-dark-theme.el --- A retro-groove colour theme for Emacs
+;;; gruvbox-dark-medium-theme.el --- A retro-groove colour theme for Emacs
 
 ;; Copyright (c) 2013 Lee Machin
diff --git a/gruvbox-light-theme.el b/gruvbox-light-medium-theme.el
similarity index 91%
copy from gruvbox-light-theme.el
copy to gruvbox-light-medium-theme.el
index b3fb18e6cc..01b5beba2d 100644
--- a/gruvbox-light-theme.el
+++ b/gruvbox-light-medium-theme.el
@@ -1,4 +1,4 @@
 ;;; gruvbox-light-theme.el --- A retro-groove colour theme for Emacs
 
 ;; Copyright (c) 2013 Lee Machin
 ;; Copyright (c) 2013-2016 Greduan
@@ -51,8 +51,8 @@
 (require 'gruvbox)
 
 (gruvbox-deftheme
- gruvbox-light
- "A retro-groove colour theme (light version)"
+ gruvbox-light-medium
+ "A retro-groove colour theme (light version, medium contrast)"
 
  ((((class color) (min-colors #xFFFFFF))        ; col 1 GUI/24bit
    ((class color) (min-colors #xFF)))           ; col 2 Xterm/256
@@ -116,13 +116,9 @@
   (gruvbox-aquamarine4     "#83A598" "#87af87")
   (gruvbox-turquoise4      "#61ACBB" "#5fafaf")
 
-  (gruvbox-bg (cl-case gruvbox-contrast
-                (hard gruvbox-dark0_hard)
-                (soft gruvbox-dark0_soft)
-                ;; Medium by default.
-                (t    gruvbox-dark0))))
+  (gruvbox-bg gruvbox-dark0))
 
- (custom-theme-set-variables 'gruvbox-light
+ (custom-theme-set-variables 'gruvbox-light-medium
                              `(ansi-color-names-vector
                                [,gruvbox-dark1
                                 ,gruvbox-neutral_red
@@ -140,10 +136,10 @@
                   (file-name-as-directory
                    (file-name-directory load-file-name))))
 
-(provide-theme 'gruvbox-light)
+(provide-theme 'gruvbox-light-medium)
 
 ;; Local Variables:
 ;; eval: (when (fboundp 'rainbow-mode) (rainbow-mode +1))
 ;; End:
 
-;;; gruvbox-light-theme.el ends here
+;;; gruvbox-light-medium-theme.el ends here
@@ -1,4 +1,4 @@
-;;; gruvbox-light-theme.el --- A retro-groove colour theme for Emacs
+;;; gruvbox-light-medium-theme.el --- A retro-groove colour theme for Emacs
 
 ;; Copyright (c) 2013 Lee Machin